# Author: Anthony Stahler
# Last updated: Apr 10, 2022
# License: Free for personal use, for commercial use please reach out to the author via the BestEdit contact page: http://bestedit.net/contact/
# The most recent version of this script can be found at http://bestedit.net/premiere-pro-xml-fix/
#
# This is a utility script to list all the files used in your projects, along with the associated index, for use with the XML shift script.
# These indexes allow you to shift each file by a different amount of frames if you wish. 
# See the XML shift script for more details.
#

# --------------------------
# VARIABLES 
# --------------------------

# change this path to whereever the files are that you'd like to get the index values from
$srcpath = "M:\movie-edits-exports\framerate-shift\"

# --------------------------
# CONSTANTS (don't touch)
# --------------------------
$targetext = "*.xml" 

# --------------------------
# --------------------------

# start processing xml files
Get-ChildItem -path ( $srcpath + $targetext ) | foreach {
    $origname1 = $_.Name
    $origname1NOext = $_.BaseName
    $origname1_normal = $origname1 -replace '[\[\]\(\)_,]', ' ' # stage 1, replace crap with spaces
    $origname1_normal = $origname1_normal -replace '\s+', '.' # stage 2, replace multiple spaces in a row with one period
    $ismatch = $origname1_normal -match '(.+)(1080p|720p)'

    if ($ismatch -eq $true)
    {
        Write-Output "Processing '$origname1'."

        $isproject = $false
        [long]$masterclip_id = -1
        $masterclip_ht = @{}
        $tmpstr = ""

        [System.IO.File]::ReadLines($srcpath + $origname1) | ForEach-Object {

                $linedata_orig = $_

                switch -regex ($linedata_orig)
                {
                    '(<clipitem )' { 
                        $masterclip_id = -1
                    }

                    '(</clipitem>)' { 
                        $masterclip_id = -1
                    }

                    '(<masterclipid>)' { 
                        $tmpstr = $linedata_orig -replace '(<masterclipid>)(.*)(</masterclipid>)', "`$2"
                        $tmpstr = $tmpstr.ToLower().Trim()

                        # make the result just the number
                        $masterclip_id = $tmpstr.Replace("masterclip-", "")
                    }

                    # found a <name> tag
                    '(<name>)(.*)(</name>)' { 
                        if ($masterclip_id -ne -1)
                        {
                            $tmpstr = $linedata_orig -replace '(<name>)(.*)(</name>)', "`$2"
                            $tmpstr = $tmpstr.Trim()

                            if ($masterclip_ht.ContainsKey($masterclip_id) -eq $false)
                            {
                                $masterclip_ht.add($masterclip_id, $tmpstr)
                            }

                            # don't want to accidentally pick up a name from a filter or something
                            $masterclip_id = -1
                        }
                    }

                    '(<project>)' { 
                        # we only want sequences, not projects, warn the user
                        $isproject = $true
                    }

                }
        }

        if ($isproject -eq $true)
        {
            Write-Output "Project detected, results may not be accurate for file: '$origname1'"
        }

        foreach ($tmppair in $masterclip_ht.GetEnumerator())
        {
            $tmpstr = "file: " + $tmppair.Value + ", index: " + $tmppair.Name
            Write-Output $tmpstr
        }

        Write-Output ""
    }
    else
    {
        Write-Output "File '$origname1' not in normal movie format (Name.Year.Resolution) or tv format (Name.S##E##.Resolution), skipping!"
    }
}




